# cdk-bar

A demo construct library created with `Projen` :-)

# sample

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
app = cdk.App()

stack = cdk.Stack(app, "my-demo-stack")

Bar(stack, "MyBar")
```
